@@ -16,6 +16,7 @@ def sign(data,cook):
         'Content-Type': 'application/json',
         'Cookie': cook,
     }
+    #print(data)
     try:
         data = requests.post(
             url=api["sign_url"],
@@ -25,8 +26,10 @@ def sign(data,cook):
         #print(data)
         if data.get("errcode") == 0:
             return "[S]Successfully"
+        if data.get('errmsg')=='不能重复回答同一问卷':
+            return "[S]Already signed"
         else:
-            return "[S]Already Clocked"
+            return "[E]error"
     
     except:
         return "[E]:Unknown"
